@@ -81,25 +81,23 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         except ValueError:
             self.cast_avg_to_float = False
 
-    def __connect(self):
-        """Connect to the database"""
-        self.connection = Database.connect(
-            server=self.settings_dict['HOST'],
-            database=self.settings_dict['NAME'],
-            user=self.settings_dict['USER'],
-            password=self.settings_dict['PASSWORD'],
-            timeout=self.command_timeout,
-            autocommit=self.autocommit,
-        )
-        # The OUTPUT clause is supported in 2005+ sql servers
-        self.features.can_return_id_from_insert = self.connection.tds_version >= Database.TDS72
-
-        connection_created.send(sender=self.__class__, connection=self)
-        return self.connection
-
     def _cursor(self):
         if self.connection is None:
-            self.__connect()
+            """Connect to the database"""
+            options = self.settings_dict.get('OPTIONS', {})
+            self.connection = Database.connect(
+                server=self.settings_dict['HOST'],
+                database=self.settings_dict['NAME'],
+                user=self.settings_dict['USER'],
+                password=self.settings_dict['PASSWORD'],
+                timeout=self.command_timeout,
+                autocommit=self.autocommit,
+                use_mars=options.get('use_mars', False),
+                load_balancer=options.get('load_balancer', None),
+            )
+            # The OUTPUT clause is supported in 2005+ sql servers
+            self.features.can_return_id_from_insert = self.connection.tds_version >= Database.TDS72
+            connection_created.send(sender=self.__class__, connection=self)
         return CursorWrapper(self.connection.cursor())
 
     def disable_constraint_checking(self):
